==> systemml-0.15.0-src.zip: systemml-0.15.0-src/src/main/java/org/apache/sysml/hops/recompile/RecompileStatus.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sysml.hops.recompile;

import java.util.HashMap;

import org.apache.sysml.runtime.matrix.MatrixCharacteristics;

public class RecompileStatus 
{
	private final HashMap<String, MatrixCharacteristics> _lastTWrites; 
	private final boolean _initialCodegen;
	
	public RecompileStatus() {
		this(false);
	}
	
	public RecompileStatus(boolean initialCodegen) {
		_lastTWrites = new HashMap<String,MatrixCharacteristics>();
		_initialCodegen = initialCodegen;
	}
	
	public HashMap<String, MatrixCharacteristics> getTWriteStats() {
		return _lastTWrites;
	}
	
	public boolean isInitialCodegen() {
		return _initialCodegen;
	}

	@Override
	public Object clone() {
		RecompileStatus ret = new RecompileStatus();
		ret._lastTWrites.putAll(_lastTWrites);
		return ret;
	}
}

==> systemml-1.2.0-src.zip: systemml-1.2.0-src/src/main/java/org/apache/sysml/hops/recompile/RecompileStatus.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.sysml.hops.recompile;

import java.util.HashMap;

import org.apache.sysml.runtime.matrix.MatrixCharacteristics;

public class RecompileStatus 
{
	private final HashMap<String, MatrixCharacteristics> _lastTWrites; 
	private final boolean _initialCodegen;
	
	public RecompileStatus() {
		this(false);
	}
	
	public RecompileStatus(boolean initialCodegen) {
		_lastTWrites = new HashMap<>();
		_initialCodegen = initialCodegen;
	}
	
	public HashMap<String, MatrixCharacteristics> getTWriteStats() {
		return _lastTWrites;
	}
	
	public boolean isInitialCodegen() {
		return _initialCodegen;
	}

	@Override
	public Object clone() {
		RecompileStatus ret = new RecompileStatus();
		ret._lastTWrites.putAll(_lastTWrites);
		return ret;
	}
}
